@@ -27,7 +27,7 @@
 #' @return A {huxtable} object
 #' @family gtsummary output types
 #' @author David Hugh-Jones
-#' @examplesIf assert_package("huxtable", boolean = TRUE)
+#' @examplesIf broom.helpers::.assert_package("huxtable", boolean = TRUE)
 #' trial %>%
 #'   dplyr::select(trt, age, grade) %>%
 #'   tbl_summary(by = trt) %>%
@@ -110,7 +110,9 @@ table_styling_to_huxtable_calls <- function(x, ...) {
   # huxtable doesn't use the markdown language `__` or `**`
   # to bold and italicize text, so removing them here
   huxtable_calls <- table_styling_to_tibble_calls(x, col_labels = FALSE)
-  huxtable_calls$tab_style_bold <- huxtable_calls$tab_style_italic <- NULL
+  huxtable_calls$tab_style_bold <-
+    huxtable_calls$tab_style_italic <-
+    huxtable_calls$fmt_missing <- NULL
 
   huxtable_calls[["huxtable"]] <- expr(huxtable::as_huxtable(add_colnames = FALSE))
 
@@ -197,8 +199,8 @@ table_styling_to_huxtable_calls <- function(x, ...) {
     x$table_styling$text_format %>%
     filter(.data$format_type == "bold") %>%
     inner_join(x$table_styling$header %>%
-      select(.data$column, column_id = .data$id),
-    by = "column"
+                 select(.data$column, column_id = .data$id),
+               by = "column"
     ) %>%
     select(.data$format_type, .data$row_numbers, .data$column_id)
 
@@ -217,8 +219,8 @@ table_styling_to_huxtable_calls <- function(x, ...) {
     x$table_styling$text_format %>%
     filter(.data$format_type == "italic") %>%
     inner_join(x$table_styling$header %>%
-      select(.data$column, column_id = .data$id),
-    by = "column"
+                 select(.data$column, column_id = .data$id),
+               by = "column"
     ) %>%
     select(.data$format_type, .data$row_numbers, .data$column_id)
 
@@ -246,18 +248,17 @@ table_styling_to_huxtable_calls <- function(x, ...) {
   # set_na_string -------------------------------------------------------
   df_fmt_missing <-
     x$table_styling$fmt_missing %>%
-    inner_join(x$table_styling$header %>%
-      select(.data$column, column_id = .data$id),
-    by = "column"
+    inner_join(
+      x$table_styling$header %>%
+        select(.data$column, column_id = .data$id),
+      by = "column"
     ) %>%
     select(.data$symbol, .data$row_numbers, .data$column_id) %>%
-    nest(location_ids = c(.data$row_numbers, .data$column_id)) %>%
+    nest(location_ids = .data$column_id) %>%
     mutate(
-      row_numbers = map(.data$location_ids, ~ pluck(.x, "row_numbers") %>% unique()),
       column_id = map(.data$location_ids, ~ pluck(.x, "column_id") %>% unique())
     )
 
-
   huxtable_calls[["fmt_missing"]] <-
     map(
       seq_len(nrow(df_fmt_missing)),
@@ -270,8 +271,6 @@ table_styling_to_huxtable_calls <- function(x, ...) {
       )
     )
 
-
-
   # insert_row ----------------------------------------------------------
   # we do this last so as to not mess up row indexes before
   col_labels <-
